TollPass class

Toll pass information

Constructors

TollPass({required String passId, String? network})
const
TollPass.fromJson(Map<String, dynamic> json)
Create from JSON response
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
network → String?
The toll pass network
final
passId → String
The toll pass identifier
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Convert to JSON for API request
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override